import customtkinter as ctk
import requests
from PIL import Image, ImageTk
from tkinter import messagebox, filedialog
import io

SHOPPING = "#00c1ff"

def user_details_frame(parent, switch_func, API_URL, token):
    """
    A two-column user details page that matches the dashboard color scheme:
      - Top bar with SHOPPING color (#00c1ff)
      - Left sidebar with a dark background (#2b2b2b)
      - Right content area (profile form, profile picture)
    """

    # Main container frame (transparent background, like dashboard)
    frame = ctk.CTkFrame(parent, fg_color="transparent")

    # ----------------- TOP BAR -----------------
    top_bar = ctk.CTkFrame(frame, fg_color=SHOPPING, height=40)
    top_bar.pack(fill="x", side="top")

    top_label = ctk.CTkLabel(
        top_bar,
        text="My Profile",
        text_color="white",
        font=("Helvetica", 16, "bold"),
    )
    top_label.pack(side="left", padx=20)

    def go_back():
        switch_func("dashboard")

    back_button = ctk.CTkButton(
        top_bar,
        text="Back",
        fg_color="white",
        text_color="black",
        command=go_back,
        width=60,
        height=30,
    )
    back_button.pack(side="right", padx=20, pady=5)

    # ----------------- MAIN SECTION (Sidebar + Content) -----------------
    main_section = ctk.CTkFrame(frame, fg_color="transparent")
    main_section.pack(fill="both", expand=True)

    # ----------------- LEFT SIDEBAR -----------------

    sidebar_frame = ctk.CTkFrame(main_section, width=200, fg_color="#2b2b2b")
    sidebar_frame.pack(side="left", fill="y")

    sidebar_title = ctk.CTkLabel(
        sidebar_frame, 
        text="Menu", 
        font=("Helvetica", 14, "bold"), 
        text_color="white"
    )
    sidebar_title.pack(pady=(10, 5))

    nav_dashboard = ctk.CTkButton(
        sidebar_frame,
        text="Dashboard",
        fg_color="#2b2b2b",
        text_color="white",
        hover_color="#3b3b3b",
        command=go_back
    )
    nav_dashboard.pack(fill="x", padx=10, pady=5)

    nav_profile = ctk.CTkButton(
        sidebar_frame,
        text="My Profile",
        fg_color="#3b3b3b",  # Active/selected state
        text_color="white",
        hover_color="#3b3b3b",
        state="disabled"
    )
    nav_profile.pack(fill="x", padx=10, pady=5)

    nav_orders = ctk.CTkButton(
        sidebar_frame,
        text="My Orders",
        fg_color="#2b2b2b",
        text_color="white",
        hover_color="#3b3b3b",
        command=lambda: switch_func("user_orders")
    )
    nav_orders.pack(fill="x", padx=10, pady=5)

    # ----------------- RIGHT CONTENT (User Details) -----------------
    content_frame = ctk.CTkFrame(main_section, fg_color="transparent")
    content_frame.pack(side="left", fill="both", expand=True, padx=20, pady=20)

    # Title / Subtitle
    title_label = ctk.CTkLabel(
        content_frame,
        text="My Profile",
        font=("Helvetica", 18, "bold"),
        text_color="white"
    )
    title_label.pack(anchor="w", pady=(0, 5))

    subtitle_label = ctk.CTkLabel(
        content_frame,
        text="Manage your profile information to keep your account secure",
        font=("Helvetica", 12),
        text_color="#cccccc"
    )
    subtitle_label.pack(anchor="w", pady=(0, 15))

    # -- Split the right content into two frames: Left form & Right picture --
    right_main = ctk.CTkFrame(content_frame, fg_color="transparent")
    right_main.pack(fill="both", expand=True)

    # LEFT FORM
    form_frame = ctk.CTkFrame(right_main, fg_color="transparent")
    form_frame.pack(side="left", fill="both", expand=True, padx=(0, 20))

    # Username
    username_label = ctk.CTkLabel(form_frame, text="Username", font=("Helvetica", 12), text_color="white")
    username_label.pack(anchor="w")
    username_entry = ctk.CTkEntry(form_frame, placeholder_text="Enter your username...")
    username_entry.pack(anchor="w", pady=(0, 10))

    # Name
    name_label = ctk.CTkLabel(form_frame, text="Name", font=("Helvetica", 12), text_color="white")
    name_label.pack(anchor="w")
    name_entry = ctk.CTkEntry(form_frame, placeholder_text="Enter your name...")
    name_entry.pack(anchor="w", pady=(0, 10))

    # Email
    email_label = ctk.CTkLabel(form_frame, text="Email", font=("Helvetica", 12), text_color="white")
    email_label.pack(anchor="w")
    email_entry = ctk.CTkEntry(form_frame, placeholder_text="Enter your email...")
    email_entry.pack(anchor="w", pady=(0, 10))

    # Phone
    phone_label = ctk.CTkLabel(form_frame, text="Phone", font=("Helvetica", 12), text_color="white")
    phone_label.pack(anchor="w")
    phone_entry = ctk.CTkEntry(form_frame, placeholder_text="Enter your phone...")
    phone_entry.pack(anchor="w", pady=(0, 10))

    # Gender
    gender_label = ctk.CTkLabel(form_frame, text="Gender", font=("Helvetica", 12), text_color="white")
    gender_label.pack(anchor="w", pady=(10, 0))

    gender_var = ctk.StringVar(value="Male")  # Default
    gender_frame = ctk.CTkFrame(form_frame, fg_color="transparent")
    gender_frame.pack(anchor="w", pady=5)

    male_radio = ctk.CTkRadioButton(gender_frame, text="Male", variable=gender_var, value="Male", text_color="white")
    female_radio = ctk.CTkRadioButton(gender_frame, text="Female", variable=gender_var, value="Female", text_color="white")
    other_radio = ctk.CTkRadioButton(gender_frame, text="Other", variable=gender_var, value="Other", text_color="white")
    male_radio.pack(side="left", padx=5)
    female_radio.pack(side="left", padx=5)
    other_radio.pack(side="left", padx=5)

    # Birthday
    birthday_label = ctk.CTkLabel(form_frame, text="Date of Birth", font=("Helvetica", 12), text_color="white")
    birthday_label.pack(anchor="w", pady=(10, 0))
    birthday_entry = ctk.CTkEntry(form_frame, placeholder_text="dd/mm/yyyy")
    birthday_entry.pack(anchor="w", pady=(0, 10))

    # Save Button
    def save_profile():
        """
        Example: Send a request to update user details.
        Adjust the endpoint and payload for your backend.
        """
        headers = {"Authorization": f"Bearer {token}"}
        payload = {
            "username": username_entry.get().strip(),
            "name": name_entry.get().strip(),
            "email": email_entry.get().strip(),
            "phone": phone_entry.get().strip(),
            "gender": gender_var.get(),
            "birthday": birthday_entry.get().strip()
        }
        try:
            resp = requests.put(f"{API_URL}/user/update", headers=headers, json=payload)
            if resp.status_code == 200:
                messagebox.showinfo("Success", "Profile updated successfully!")
            else:
                messagebox.showerror("Error", "Unable to update profile.")
        except Exception as e:
            messagebox.showerror("Error", f"Request error: {e}")

    save_button = ctk.CTkButton(
        form_frame,
        text="Save",
        fg_color=SHOPPING,  # #00c1ff
        text_color="white",
        command=save_profile,
        width=80
    )
    save_button.pack(anchor="w", pady=(20, 10))

    # RIGHT PICTURE SECTION
    pic_frame = ctk.CTkFrame(right_main, fg_color="transparent")
    pic_frame.pack(side="left", fill="both", expand=True)

    pic_label = ctk.CTkLabel(pic_frame, text="Profile Picture", font=("Helvetica", 12, "bold"), text_color="white")
    pic_label.pack(anchor="w", pady=(0, 10))

    photo_label = ctk.CTkLabel(pic_frame, text="No image", text_color="white")
    photo_label.pack(anchor="w", pady=(0, 10))

    def choose_photo():
        """
        Let the user pick a photo from their files.
        Then optionally upload it or just display it.
        """
        file_path = filedialog.askopenfilename(
            title="Choose a Profile Picture",
            filetypes=[("Image Files", "*.png *.jpg *.jpeg *.gif")]
        )
        if file_path:
            # Display chosen image
            try:
                pil_img = Image.open(file_path).resize((100, 100))
                tk_img = ImageTk.PhotoImage(pil_img)
                photo_label.configure(image=tk_img, text="")
                photo_label.image = tk_img

                # Optionally, upload the file to your server:
                # headers = {"Authorization": f"Bearer {token}"}
                # with open(file_path, 'rb') as f:
                #     requests.post(f'{API_URL}/user/upload_photo', files={'file': f}, headers=headers)
            except Exception as e:
                print(f"Image load error: {e}")
                messagebox.showerror("Error", "Cannot load the image.")

    change_photo_button = ctk.CTkButton(
        pic_frame,
        text="Choose Image",
        fg_color="white",
        text_color="black",
        command=choose_photo,
        width=80
    )
    change_photo_button.pack(anchor="w")

    # Fetch existing user info (if needed)
    def fetch_user_info():
        """
        Fetch the user's existing data to populate the form fields.
        """
        headers = {"Authorization": f"Bearer {token}"}
        try:
            resp = requests.get(f"{API_URL}/user/profile", headers=headers)
            if resp.status_code == 200:
                data = resp.json()
                username_entry.delete(0, "end")
                username_entry.insert(0, data.get("username", ""))
                name_entry.delete(0, "end")
                name_entry.insert(0, data.get("name", ""))
                email_entry.delete(0, "end")
                email_entry.insert(0, data.get("email", ""))
                phone_entry.delete(0, "end")
                phone_entry.insert(0, data.get("phone", ""))
                gender_var.set(data.get("gender", "Male"))
                birthday_entry.delete(0, "end")
                birthday_entry.insert(0, data.get("birthday", ""))

                # If there's a profile picture URL, load it
                pic_url = data.get("photo_url")
                if pic_url:
                    try:
                        resp_pic = requests.get(pic_url)
                        if resp_pic.status_code == 200:
                            pil_img = Image.open(io.BytesIO(resp_pic.content)).resize((100, 100))
                            tk_img = ImageTk.PhotoImage(pil_img)
                            photo_label.configure(image=tk_img, text="")
                            photo_label.image = tk_img
                    except Exception as e:
                        print(f"Profile picture load error: {e}")
            else:
                messagebox.showerror("Error", "Unable to retrieve user information.")
        except Exception as e:
            messagebox.showerror("Error", f"Request error: {e}")

    fetch_user_info()

    return frame
